import axios from "axios";
import { MessageBox, Message, Loading } from "element-ui";
import { refresh } from "@/api/login.js";
import router from "@/router";
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  timeout: 100000,
});
let isShowLoading = false;
let loading = null;
// 请求拦截器
service.interceptors.request.use(
  (config) => {
    const user = sessionStorage.getItem("user")
      ? JSON.parse(sessionStorage.getItem("user"))
      : "";
    if (user.token) {
      config.headers["Authorization"] = user.token;
    }
    if (config.url.indexOf("token/refresh") > -1) {
      config.headers["refresh-token"] = user.refreshToken;
    } else {
      config.headers["refresh-token"] = "";
    }
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);
// 响应拦截器
service.interceptors.response.use(
  (response) => {
    if (!isShowLoading) {
      loading = Loading.service({
        lock: true,
        text: "加载中",
        background: "rgba(0, 0, 0, 0.5)",
      });
      isShowLoading = true;
    }
    const res = response.data;
    //如果接口返回流但是错误码又是json
    if (response.config?.responseType == "blob") {
      if (response.headers["content-type"]?.indexOf("application/json") > -1) {
        const reader = new FileReader();
        reader.onload = function () {
          const message = JSON.parse(reader.result);
          if (message.code == 206) {
            resetLogin();
          } else if (message.code == 203) {
            refreshToken();
          }
        };
        reader.readAsText(response.data);
        return;
      }
    }

    //如果是
    const status = Number(res.code) || 1;
    if (isShowLoading) {
      isShowLoading = false;
      loading.close();
    }
    if (status !== 1) {
      if (res.code === 206) {
        // to re-login
        resetLogin();
      } else if (res.code === 203) {
        refreshToken();
      } else {
        Message({
          message: res.message || res.msg,
          type: "error",
          duration: 5 * 1000,
        });
      }
      return Promise.reject(new Error(res.msg || "Error"));
    } else {
      return response;
    }
  },
  (error) => {
    Message({
      message: "网络异常",
      type: "error",
      duration: 5 * 1000,
    });
    if (isShowLoading) {
      isShowLoading = false;
      loading.close();
    }
    return Promise.reject(error);
  }
);
//重新登录
function resetLogin() {
  if (document.getElementsByClassName("el-message-box").length == 0) {
    MessageBox.confirm("登录已失效, 请重新登录", "确认登出", {
      confirmButtonText: "重新登录",
      showCancelButton: false,
      showClose: false,
      closeOnPressEscape: false,
      closeOnClickModal: false,
      type: "warning",
    }).then(() => {
      var box = document.querySelector(".el-message-box__wrapper");
      box.remove();
      router.push("/login");
      sessionStorage.removeItem("user");
    });
  }
}
function refreshToken() {
  //刷新token
  refresh().then((res) => {
    if (res && res.data.code == 200) {
      const user = sessionStorage.getItem("user");
      if (user) {
        let obj = JSON.parse(sessionStorage.getItem("user"));
        obj.token = res.headers.authorization;
        sessionStorage.setItem("user", JSON.stringify(obj));
      }
    }
  });
}
export default service;
