export default class Utils {
  // 当前日期
  static todayDate() {
    let dt, y, m, d, w;
    dt = new Date();
    y = dt.getFullYear();
    m = dt.getMonth() + 1;
    d = dt.getDate();
    w = dt.getDay();
    let weeks = ['天', '一', '二', '三', '四', '五', '六'];
    return `${y} 年 ${m.toString().padStart(2, '0')} 月 ${d.toString().padStart(2, '0')} 日 星期${weeks[w]}`;
  }

  // 浏览器全屏
  static fullScreen() {
    let isFull = document.isFullScreen || document.mozIsFullScreen || document.webkitIsFullScreen;

    // 判断是否全屏
    if (isFull) {
      let close = document.exitFullscreen || document.webkitCancelFullScreen || document.mozCancelFullScreen || document.msExitFullscreen;
      close && close.call(document);
    } else {
      let docElm = document.documentElement;
      let open = docElm.requestFullScreen || docElm.webkitRequestFullScreen || docElm.mozRequestFullScreen || docElm.msRequestFullscreen;
      open && open.call(docElm);
    }
  }
  /**
   * 修正浮点误差
   * @param {Number|String, Number, Boolean} //数值，精确的小数点位数，是否做千分位格式化
   * @returns {String}
   */
  static fixFloat(num, n, thousands) {
    let regNum = /\d/;
    let res = '';
    let minus = '';
    if (num || num === 0) {
      if (num < 0) {
        minus = '-';
        num *= -1; //确保都是正的 参与运算
      }
      if (num && regNum.test(num)) {
        n = n === undefined ? 0 : n; //小数点位数
        let intPart = parseInt(num);
        let floatPart = '';
        if (n) {
          if (intPart) {
            floatPart = Math.round((num % intPart) * Math.pow(10, n)) + '';
          } else {
            floatPart = Math.round(num * Math.pow(10, n)) + '';
          }
          while (floatPart.length < n) {
            floatPart = '0' + floatPart;
          }
        }
        let reg = /\d{1,3}(?=(\d{3})+$)/g;
        res = thousands ? (intPart + '').replace(reg, '$&,') : intPart;
        res = floatPart ? minus + res + '.' + floatPart : minus + res;
      } else if (regNum.test(num) && Number(num) === 0) {
        res = Number(num) + '';
        if (n) {
          let floatPart = '';
          while (floatPart.length < n) {
            floatPart += '0';
          }
          res += '.' + floatPart;
        }
      }
    }
    return res;
  }
  /**
   * 格式化时间
   * @param {Number|String, String, Boolean} //时间，日期连接符，是否显示时间
   * @returns {String}
   */
  static formatDate(date, flag, showTime) {
    // console.log("flag:"+flag);
    flag = flag === undefined ? '-' : flag;
    let newDate = new Date(date);
    if (newDate.getTime()) {
      let y = newDate.getFullYear();
      let m = newDate.getMonth() + 1;
      m = m < 10 ? '0' + m : m;
      let d = newDate.getDate();
      d = d < 10 ? '0' + d : d;
      let result = y + flag + m + flag + d;
      if (showTime === true) {
        let h = newDate.getHours();
        h = h < 10 ? '0' + h : h;
        let min = newDate.getMinutes();
        min = min < 10 ? '0' + min : min;
        let sec = newDate.getSeconds();
        sec = sec < 10 ? '0' + sec : sec;
        result += ' ' + h + ':' + min + ':' + sec;
      } else if (showTime) {
        result += ' ' + showTime;
      }
      return result;
    } else {
      return '';
    }
  }
  /**
   * 自定义确认框
   * @param {Object, Function}  //option按element官网的参数即可，hotWord是自定义参数
   * @returns {undefined/Promise}
   */
  static superConfirm(option, callback) {
    const newOption = {
      message: `确定${option ? option.hotWord || '' : ''}吗？`,
      confirmButtonText: '确定',
      cancelButtonText: '取消',
      type: 'warning',
      ...option,
    };
    //第一种写法，传入回调
    if (callback) {
      this.$confirm(null, newOption)
        .then(callback)
        .catch(() => {});
      return undefined;
    } else {
      //第二种写法，不用回调
      return new Promise((resolve) => {
        this.$confirm(null, newOption)
          .then(() => resolve(true))
          .catch(() => resolve(false));
      });
    }
  }
  //格式化 菜单列表
  static formatMenu(menu, isMenu) {
    const res = [];
    menu.forEach((v) => {
      if (isMenu) {
        if (v.isActive) {
          let children = v.children.length ? this.formatMenu(v.children, isMenu) : null;
          res.push({ ...v, children });
        }
      } else {
        let children = v.children.length ? this.formatMenu(v.children, isMenu) : null;
        res.push({ ...v, children });
      }
    });
    return res;
  }
  //判断路由是否有权限访问
  static isAuthorMenu(menu, path) {
    let res = false;
    for (let i = 0; i < menu.length; i++) {
        if (menu[i].code === path) {
          res = true;
          break;
        } else if (menu[i].children.length) {
          res = this.isAuthorMenu(menu[i].children, path);
          if (res) {
            break;
          }
        }
      
    }
    return res;
  }
  static timestampToTime(date,showTime) {
   let  flag  ='-';
    let newDate = new Date(date);
    if (newDate.getTime()) {
      
      let y = newDate.getFullYear();
      let m = newDate.getMonth() + 1;
      m = m < 10 ? '0' + m : m;
      let d = newDate.getDate();
      d = d < 10 ? '0' + d : d;
      if (date.indexOf('T') > -1) {
        let arr = date.split('T')[0].split('-')
        m = arr[1];
        d = arr[2]
      }
      let result = y + flag + m + flag + d;
      if (showTime === true) {
      // 时区有问题差8个小时
        if (date.indexOf('T') > -1) { 
          newDate = new Date(new Date(date).getTime() - 8*60*60*10000)
        }
        let h = newDate.getHours();
        h = h < 10 ? '0' + h : h;
        let min = newDate.getMinutes();
        min = min < 10 ? '0' + min : min;
        let sec = newDate.getSeconds();
        sec = sec < 10 ? '0' + sec : sec;
        result += ' ' + h + ':' + min + ':' + sec;
      } else if (showTime) {
        result += ' ' + showTime;
      }
      return result;
    } else {
      return '';
    }
  }
}
