import Vue from "vue";
import Router from "vue-router";
import Utils from "./common/utils";
//基础模块
const Login = () => import("./views/login"); //登录页
const Layout = () => import("./views/layout"); //菜单及页面框架
const Index = () => import("./views/train/chupiao.vue"); //默认主页
const NotFound = () => import("./views/notFound.vue"); //404页面
Vue.use(Router);

const router = new Router({
  base: process.env.BASE_URL,
  routes: [
    {
      path: "/login",
      component: Login,
    },
    {
      path: "/",
      component: Layout,
      redirect: "/index",
      children: [
        {
          path: "/index",
          name: "index",
          component: Index,
          meta: { isAuthor: false },
        },
        {
          path: "/refound",
          name: "refound",
          component: () => import("@/views/train/tuipiao.vue"),
          meta: { isAuthor: false },
        },
        {
          path: "/change",
          name: "change",
          component: () => import("@/views/train/gaiqian.vue"),
          meta: { isAuthor: false },
        },
        {
          path: "/ipAddress",
          name: "ipAddress",
          component: () => import("@/views/train/ipAddress.vue"),
          meta: { isAuthor: false },
        },
        {
          path: "/404",
          component: NotFound,
        },
      ],
    },
    {
      path: "/system",
      redirect: "/system/userManage",
      component: Layout,
      children: [
        {
          path: "/system/userManage",
          name: "userManage",
          component: () => import("@/views/system/userManage.vue"),
          meta: { isAuthor: true },
        },
        {
          path: "/system/roleManage",
          name: "roleManage",
          component: () => import("@/views/system/roleManage.vue"),
          meta: { isAuthor: true },
        },
        {
          path: "/system/authorManage",
          name: "authorManage",
          component: () => import("@/views/system/authorManage.vue"),
          meta: { isAuthor: true },
        },
      ],
    },
    {
      path: "*",
      redirect: { path: "/404" },
    },
  ],
});

// 全局路由守卫
router.beforeEach((to, from, next) => {
  const LOGINURL = "/login";
  const user = sessionStorage.getItem("user");
  //跳到登录页，清除登录信息
  if (to.path === LOGINURL) {
    sessionStorage.removeItem("user");
  }
  // 判断是否登录
  if (!user && to.path !== LOGINURL) {
    next({ path: LOGINURL });
  } else {
    //判断是否需要验证
    if (to.meta.isAuthor) {
      const authorList = JSON.parse(user).authorList;
      //判断是否有权限访问
      if (Utils.isAuthorMenu(authorList, to.path)) {
        next();
      } else {
        next({ path: from.path });
        // next();
      }
    } else {
      next();
    }
  }
});

export default router;
