import variables from "@/style/element-variables.scss";
const state = {
  // 用户访问过的页面 就是标签栏导航显示的一个个 tag 数组集合
  visitedViews: [],
  // 实际 keep-alive 的路由。可以在配置路由的时候通过 meta.noCache 来设置是否需要缓存这个路由 默认都缓存。
  cachedViews: [],
  isCollapse: false,
  theme: variables.theme || localStorage.getItem("themeColor") || "#409EFF",
  cardTypes: [
    { label: "二代身份证", value: "1" },
    { label: "港澳居民来往内地通行证", value: "C" },
    { label: "台湾居民来往大陆通行证", value: "G" },
    { label: "护照", value: "B" },
    { label: "港澳台居民居住证", value: "I" },
    { label: "外国人永久居留身份证", value: "H" },
  ],
  userTypes: [
    { label: "成人", value: "1" },
    { label: "儿童", value: "2" },
  ],
  userTypeObj: {
    1: "成人",
    2: "儿童",
  },
  cardTypeObj: {
    1: "二代身份证",
    C: "港澳居民来往内地通行证",
    G: "台湾居民来往大陆通行证",
    B: "护照",
    I: "港澳台居民居住证",
    H: "外国人永久居留身份证",
  },
};

const mutations = {
  //修改色彩
  CHANFETHEMECOLOR: (state, { key, value }) => {
    if (state[key]) {
      state[key] = value;
    }
  },
  switchCollapse(state) {
    state.isCollapse = !state.isCollapse;
  },
  // 添加标签
  ADD_VISITED_VIEW: (state, view) => {
    // 如果标签跳转的路由存在就不添加，否则就添加进标签组
    if (state.visitedViews.some((v) => v.path === view.path)) return;
    state.visitedViews.push(
      Object.assign({}, view, {
        title: view.title || "no-name",
      })
    );
  },
  // 添加缓存标签
  ADD_CACHED_VIEW: (state, view) => {
    // 已存在缓存就不缓存了
    if (state.cachedViews.includes(view.name)) return;
    if (view.meta && !view.meta.noCache) {
      state.cachedViews.push(view.name);
    }
  },
  // 删除选择的标签
  DEL_VISITED_VIEW: (state, view) => {
    for (const [i, v] of state.visitedViews.entries()) {
      if (v.path === view.path) {
        state.visitedViews.splice(i, 1);
        break;
      }
    }
  },
  // 删除缓存标签
  DEL_CACHED_VIEW: (state, view) => {
    const index = state.cachedViews.indexOf(view.name);
    index > -1 && state.cachedViews.splice(index, 1);
  },
  UPDATE_VISITED_VIEW: (state, view) => {
    for (let v of state.visitedViews) {
      if (v.path === view.path) {
        v = Object.assign(v, view);
        break;
      }
    }
  },
};

const actions = {
  // 新增当前路由标签和标签缓存
  addView({ dispatch }, view) {
    dispatch("addVisitedView", view);
    dispatch("addCachedView", view);
  },
  // 新增当前路由标签
  addVisitedView({ commit }, view) {
    commit("ADD_VISITED_VIEW", view);
  },
  // 新增当前路由标签缓存
  addCachedView({ commit }, view) {
    commit("ADD_CACHED_VIEW", view);
  },
  // 删除当前路由标签和标签缓存
  delView({ dispatch, state }, view) {
    return new Promise((resolve) => {
      dispatch("delVisitedView", view);
      dispatch("delCachedView", view);
      resolve({
        visitedViews: [...state.visitedViews],
        cachedViews: [...state.cachedViews],
      });
    });
  },
  // 删除当前路由标签
  delVisitedView({ commit, state }, view) {
    return new Promise((resolve) => {
      commit("DEL_VISITED_VIEW", view);
      resolve([...state.visitedViews]);
    });
  },
  // 删除当前路由标签缓存
  delCachedView({ commit, state }, view) {
    return new Promise((resolve) => {
      commit("DEL_CACHED_VIEW", view);
      resolve([...state.cachedViews]);
    });
  },
  updateVisitedView({ commit }, view) {
    commit("UPDATE_VISITED_VIEW", view);
  },
  //修改主题色
  setThemeConfig({ commit }, data) {
    commit("CHANFETHEMECOLOR", data);
    localStorage.setItem("themeColor", data.value);
  },
};

export default {
  namespaced: true,
  state,
  mutations,
  actions,
};
