//历史纪录
const SEARCH_HISTORY_KEY = 'searchHistory';  
// 从localStorage中获取搜索历史，如果不存在则返回一个空的Map  
export function getSearchHistoryFromLocalStorage() {  
    const historyString = localStorage.getItem(SEARCH_HISTORY_KEY);  
    if (historyString) {  
        // 使用JSON.parse将字符串解析回Map对象  
        return new Map(JSON.parse(historyString));  
    } else {  
        return new Map();  
    }  
}  
  
// 将搜索历史保存到localStorage中  
export function saveSearchHistoryToLocalStorage(searchHistory) {  
    // 使用Array.from和map将Map对象转换为数组，再转换为JSON字符串  
    const historyString = JSON.stringify(Array.from(searchHistory.entries()));  
    localStorage.setItem(SEARCH_HISTORY_KEY, historyString);  
}  
  
// 一个函数来添加搜索记录，其中searchContent是要保存的对象  
export function addSearchHistory(searchContent,searchHistory) {  
    const searchKey = JSON.stringify(searchContent);  
      
    if (!searchHistory.has(searchKey)) {  
        // 添加时间戳或其他信息  
        const item = { timestamp: new Date() };  
        searchHistory.set(searchKey, item); 
        if (searchHistory.size > 10) {  
          // 获取最旧的记录的键  
          const oldestKey = searchHistory.entries().next().value[0];  
          searchHistory.delete(oldestKey);  
       }
        // 保存更新后的搜索历史到localStorage  
        saveSearchHistoryToLocalStorage(searchHistory);  
    }  
}  
  
// 一个函数来获取搜索历史记录  
export function getSearchHistory(searchHistory) {  
    return Array.from(searchHistory.entries()).map(([searchKey, value]) => ({  
        searchContent: JSON.parse(searchKey),  
        timestamp: value.timestamp  
    }));  
}  