let $math = require("mathjs");
export const math = {
  add() {
    //加
    return comp("add", arguments);
  },
  subtract() {
    //减
    return comp("subtract", arguments);
  },
  multiply() {
    //乘
    return comp("multiply", arguments);
  },
  divide() {
    // 除
    return comp("divide", arguments);
  },
};

function comp(_func, args) {
  let t = $math.chain($math.bignumber(args[0]));
  for (let i = 1; i < args.length; i++) {
    t = t[_func]($math.bignumber(args[i]));
  }
  // 防止超过6位使用科学计数法
  return parseFloat(t.done());
}
export function todayDate(date) {
  let dt, m, d, w, y;
  dt = new Date(date);
  y = dt.getFullYear();
  m = dt.getMonth() + 1;
  d = dt.getDate();
  w = dt.getDay();
  let weeks = ["天", "一", "二", "三", "四", "五", "六"];
  return {
    date: `${m.toString().padStart(2, "0")}-${d.toString().padStart(2, "0")}`,
    week: `周${weeks[w]}`,
    year: y,
  };
  // return `${y} 年 ${m.toString().padStart(2, '0')} 月 ${d.toString().padStart(2, '0')} 日 星期${weeks[w]}`;
}
export function formatDate(date, flag, showTime) {
  // console.log("flag:"+flag);
  flag = flag === undefined ? "-" : flag;
  let newDate = new Date(date);
  if (newDate.getTime()) {
    let y = newDate.getFullYear();
    let m = newDate.getMonth() + 1;
    m = m < 10 ? "0" + m : m;
    let d = newDate.getDate();
    d = d < 10 ? "0" + d : d;
    let result = y + flag + m + flag + d;
    if (showTime === true) {
      let h = newDate.getHours();
      h = h < 10 ? "0" + h : h;
      let min = newDate.getMinutes();
      min = min < 10 ? "0" + min : min;
      let sec = newDate.getSeconds();
      sec = sec < 10 ? "0" + sec : sec;
      result += " " + h + ":" + min + ":" + sec;
    } else if (showTime) {
      result += " " + showTime;
    }
    return result;
  } else {
    return "";
  }
}
export function journeyDays(time, startTime, queryDate) {
  //计算第几日到达
  let startDate = queryDate + " " + startTime;
  if (time) {
    let h = time.split(":")[0];
    let m = time.split(":")[1];
    let num = parseInt(h);
    let y = parseInt(num / 24); //多少整天
    let yu = parseInt(num % 24);
    let hm =
      +new Date(startDate) + yu * 60 * 60 * 1000 + parseInt(m) * 1000 * 60;
    let ymd = formatDate(hm, "-", false);
    // 把小时的余数与分钟数转成毫秒与出发时间相加 再转成时间格式 YYYY-MM-DD 如果与出发时间相等就不用加1如果不相等就要加1
    if (ymd != queryDate) {
      y = y + 1;
    }
    if (y > 0) {
      if (y == 1) {
        // "次日到达"
        return 1;
      } else {
        // y + "日后到达"
        return y;
      }
    } else {
      // "当日到达"0
      return 0;
    }
  }
}
export function fullTime(time, startTime, queryDate) {
  //返回完整时间
  let startDate = queryDate + " " + startTime;
  if (time) {
    let h = time.split(":")[0];
    let m = time.split(":")[1];
    let hm =
      +new Date(startDate) +
      parseInt(h) * 60 * 60 * 1000 +
      parseInt(m) * 1000 * 60;
    let ymd = formatDate(hm, "-", true);
    return ymd;
  }
}
export function differFromDate(startTime, endTime, type = "hh-mm") {
  if (startTime && endTime) {
    let startDate = new Date(startTime).getTime();
    let endDate = new Date(endTime).getTime();
    let differ = endDate - startDate;
    let h = parseInt(differ / 3600000); //小时
    let yu = parseInt(differ % 3600000); //小时后的余数
    let m = parseInt(yu / 60000); //分钟
    if (type == "array") {
      return h + ":" + m;
    } else {
      return h + "小时" + m + "分";
    }
  } else {
    return "--";
  }
}
// 中转行程数据格式处理
export function moreTrip(data = []) {
  return data.map((item) => {
    let obj = {
      firstTrip: { ...item[0] },
      secondTrip: { ...item[1] },
    };
    obj.loading = false;
    obj.id =
      obj.firstTrip?.arriveStationCode +
      obj.firstTrip?.trainNo +
      obj.firstTrip?.trainCode +
      obj.firstTrip?.departureStationCode +
      obj.secondTrip?.arriveStationCode +
      obj.secondTrip?.trainNo +
      obj.secondTrip?.trainCode +
      obj.secondTrip?.departureStationCode;
    obj.firstTrip.queryDateMM = ""; // 第一行程出发的年月日
    obj.firstTrip.fullArrivalTime = ""; //到达时间
    obj.secondTrip.queryDateMM = ""; // 第二行程出发的年月日
    obj.secondTrip.fullArrivalTime = ""; //到达时间
    obj.firstTrip.journeyDays = ""; //行程天数
    obj.secondTrip.journeyDays = ""; // 行程天数
    let arr = ["firstTrip", "secondTrip"];
    for (var key in arr) {
      let name = arr[key];
      if (obj[name].queryDate) {
        let str =
          obj[name]?.queryDate?.substring(0, 4) +
          "-" +
          obj[name]?.queryDate?.substring(4, 6) +
          "-" +
          obj[name]?.queryDate?.substring(6, 8);
        obj[name].queryDateMM = str;
        //第一、二行程到达时间
        obj[name].fullArrivalTime = fullTime(
          obj[name]?.distanceTime,
          obj[name]?.departureTime,
          str
        );
        //一、二单独行程天数 journeyDays
        obj[name].journeyDays = journeyDays(
          obj[name]?.distanceTime,
          obj[name]?.departureTime,
          str
        );
      }
      // 一、二行程是否有座并计算价格
      if (obj[name].ticketInfoVos) {
        obj[name].ticketInfoVos = obj[name].ticketInfoVos.filter((item) => {
          return item.desc != "无票";
        });
      }
    }
    //两个行程都有票时才能预订
    obj.isItPossibleTo = false;
    obj.price = 0;
    obj.firstPiao = {};
    obj.secondPiao = {};
    if (
      obj.firstTrip?.ticketInfoVos?.length > 0 &&
      obj.secondTrip?.ticketInfoVos?.length > 0
    ) {
      //排序
      obj.firstTrip.ticketInfoVos = obj.firstTrip?.ticketInfoVos?.sort(
        (a, b) => {
          return parseFloat(a.price) - parseFloat(b.price);
        }
      );
      obj.secondTrip.ticketInfoVos = obj.secondTrip?.ticketInfoVos?.sort(
        (a, b) => {
          return parseFloat(a.price) - parseFloat(b.price);
        }
      );
      obj.isItPossibleTo = true;
      obj.firstPiao = {
        ...obj.firstTrip?.ticketInfoVos[0],
        trainCode: obj.firstTrip?.trainCode,
      };
      obj.secondPiao = {
        ...obj.secondTrip?.ticketInfoVos[0],
        trainCode: obj.secondTrip?.trainCode,
      };
      obj.price = math.add(obj.firstPiao.price, obj.secondPiao.price);
    }
    // 计算行程总耗时
    obj.allLongTime = differFromDate(
      obj.firstTrip.queryDateMM + " " + obj.firstTrip?.departureTime,
      obj.secondTrip.fullArrivalTime
    );
    obj.allLong = differFromDate(
      obj.firstTrip.queryDateMM + " " + obj.firstTrip?.departureTime,
      obj.secondTrip.fullArrivalTime,
      "array"
    );
    // 换乘停留时间
    obj.transferTime = differFromDate(
      obj.firstTrip.fullArrivalTime,
      obj.secondTrip.queryDateMM + " " + obj.secondTrip?.departureTime
    );
    // 总行程是否跨天
    obj.journeyDays = journeyDays(
      obj.allLong,
      obj.firstTrip?.departureTime,
      obj.firstTrip?.queryDateMM
    );
    return obj;
  });
}
